@@ -15,7 +15,7 @@ class Publisher:
       attrs['type'] = e['type']
       _, body = to_structured(e)
       # then publish
-      self.p.publish(self.topic_name, body, **attrs)
+      self.p.publish(self.topic, body, **attrs)
 
 
 def ips_topic(location: str = 'london', gcp_project: str = 'vipro-core-services') -> Publisher:
